/****************************************************************************
** Meta object code from reading C++ file 'knotificationmanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../knotifications-5.116.0/src/knotificationmanager_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knotificationmanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNotificationManager_t {
    QByteArrayData data[15];
    char stringdata0[205];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNotificationManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNotificationManager_t qt_meta_stringdata_KNotificationManager = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KNotificationManager"
QT_MOC_LITERAL(1, 21, 18), // "notificationClosed"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 26), // "xdgActivationTokenReceived"
QT_MOC_LITERAL(4, 68, 2), // "id"
QT_MOC_LITERAL(5, 71, 5), // "token"
QT_MOC_LITERAL(6, 77, 21), // "notificationActivated"
QT_MOC_LITERAL(7, 99, 6), // "action"
QT_MOC_LITERAL(8, 106, 19), // "notificationReplied"
QT_MOC_LITERAL(9, 126, 4), // "text"
QT_MOC_LITERAL(10, 131, 20), // "notifyPluginFinished"
QT_MOC_LITERAL(11, 152, 14), // "KNotification*"
QT_MOC_LITERAL(12, 167, 12), // "notification"
QT_MOC_LITERAL(13, 180, 20), // "reparseConfiguration"
QT_MOC_LITERAL(14, 201, 3) // "app"

    },
    "KNotificationManager\0notificationClosed\0"
    "\0xdgActivationTokenReceived\0id\0token\0"
    "notificationActivated\0action\0"
    "notificationReplied\0text\0notifyPluginFinished\0"
    "KNotification*\0notification\0"
    "reparseConfiguration\0app"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNotificationManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x08 /* Private */,
       3,    2,   45,    2, 0x08 /* Private */,
       6,    2,   50,    2, 0x08 /* Private */,
       8,    2,   55,    2, 0x08 /* Private */,
      10,    1,   60,    2, 0x08 /* Private */,
      13,    1,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    4,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::QString,   14,

       0        // eod
};

void KNotificationManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KNotificationManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->notificationClosed(); break;
        case 1: _t->xdgActivationTokenReceived((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->notificationActivated((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->notificationReplied((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->notifyPluginFinished((*reinterpret_cast< KNotification*(*)>(_a[1]))); break;
        case 5: _t->reparseConfiguration((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KNotification* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KNotificationManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KNotificationManager.data,
    qt_meta_data_KNotificationManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KNotificationManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNotificationManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNotificationManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNotificationManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
